@@ -1,5 +1,8 @@
+# Copyright (c) Microsoft Corporation. All rights reserved.
+# Licensed under the MIT License.
 from typing import List
 import traceback
+from traceback import StackSummary, extract_tb
 
 
 def extend_exception_message(exc: Exception, msg: str) -> Exception:
@@ -14,28 +17,23 @@ def extend_exception_message(exc: Exception, msg: str) -> Exception:
 
 
 def marshall_exception_trace(exc: Exception) -> str:
-    stack_summary: traceback.StackSummary = traceback.extract_tb(
-        exc.__traceback__)
+    stack_summary: StackSummary = extract_tb(exc.__traceback__)
     if isinstance(exc, ModuleNotFoundError):
         stack_summary = _marshall_module_not_found_error(stack_summary)
     return ''.join(stack_summary.format())
 
 
-def _marshall_module_not_found_error(
-    tbss: traceback.StackSummary
-) -> traceback.StackSummary:
+def _marshall_module_not_found_error(tbss: StackSummary) -> StackSummary:
     tbss = _remove_frame_from_stack(tbss, '<frozen importlib._bootstrap>')
     tbss = _remove_frame_from_stack(
         tbss, '<frozen importlib._bootstrap_external>')
     return tbss
 
 
-def _remove_frame_from_stack(
-    tbss: traceback.StackSummary,
-    framename: str
-) -> traceback.StackSummary:
-    filtered_stack_list: List[traceback.FrameSummary] = list(
-        filter(lambda frame: getattr(frame, 'filename') != framename, tbss))
-    filtered_stack: traceback.StackSummary = traceback.StackSummary.from_list(
-        filtered_stack_list)
+def _remove_frame_from_stack(tbss: StackSummary,
+                             framename: str) -> StackSummary:
+    filtered_stack_list: List[traceback.FrameSummary] = \
+        list(filter(lambda frame: getattr(frame,
+                                          'filename') != framename, tbss))
+    filtered_stack: StackSummary = StackSummary.from_list(filtered_stack_list)
     return filtered_stack
