@@ -1,15 +1,15 @@
+# Copyright (c) Microsoft Corporation. All rights reserved.
+# Licensed under the MIT License.
 import json
 
 import azure.functions as func
 
 
 def main(event: func.EventGridEvent) -> str:
-    result = json.dumps({
+    return json.dumps({
         'id': event.id,
         'data': event.get_json(),
         'topic': event.topic,
         'subject': event.subject,
         'event_type': event.event_type,
     })
-
-    return result
