@@ -11,12 +11,14 @@ def main(msg: azf.ServiceBusMessage) -> str:
         'body': msg.get_body().decode('utf-8'),
         'content_type': msg.content_type,
         'delivery_count': msg.delivery_count,
-        'expiration_time': msg.expiration_time,
+        'expiration_time': (msg.expiration_time.isoformat() if
+                            msg.expiration_time else None),
         'label': msg.label,
         'partition_key': msg.partition_key,
         'reply_to': msg.reply_to,
         'reply_to_session_id': msg.reply_to_session_id,
-        'scheduled_enqueue_time': msg.scheduled_enqueue_time,
+        'scheduled_enqueue_time': (msg.scheduled_enqueue_time.isoformat() if
+                                   msg.scheduled_enqueue_time else None),
         'session_id': msg.session_id,
         'time_to_live': msg.time_to_live,
         'to': msg.to,
