@@ -1,3 +1,5 @@
+# Copyright (c) Microsoft Corporation. All rights reserved.
+# Licensed under the MIT License.
 # Imported from https://github.com/ilevkivskyi/typing_inspect/blob/168fa6f7c5c55f720ce6282727211cf4cf6368f6/test_typing_inspect.py
 # Author: Ivan Levkivskyi
 # License: MIT
@@ -19,9 +21,9 @@ NEW_TYPING = sys.version_info[:3] >= (3, 7, 0)  # PEP 560
 class IsUtilityTestCase(TestCase):
     def sample_test(self, fun, samples, nonsamples):
         for s in samples:
-            self.assertTrue(fun(s))
+            self.assertTrue(fun(s), f"{s} type expected in {samples}")
         for s in nonsamples:
-            self.assertFalse(fun(s))
+            self.assertFalse(fun(s), f"{s} type expected in {nonsamples}")
 
     def test_generic(self):
         T = TypeVar('T')
